==> ItarjConsole-0.1.tar.gz: ItarjConsole-0.1/README.md <==
# Itarj Console

Itarj Console is a CLI application created with python. This application is aimed at reducing the rate at which internet users fall for job scams. Users of the application can be able to search the database for Job openings that have been flagged as **scams**.

## Features

Itarj Console provides the following features:

* Beautiful User interface:

  We know that console applications can look plain sometimes 😐. So we decided to spice it up with some colour 😁.

  ![Itarj Cli](https://res.cloudinary.com/damianson/image/upload/w_1000,ar_16:9,c_fill,g_auto,e_sharpen/v1590695595/itarj_demo_mzi0ge.jpg)
* Users can create posts, these posts will be uploaded to the database and other users will be able to see it.
* Users can also search the database for posts using keyword, and the results will be automatically returned through a website on the browser.

  ![Itarj search](https://res.cloudinary.com/damianson/image/upload/w_1000,ar_16:9,c_fill,g_auto,e_sharpen/v1590695596/itarj_search_result_jjrtpv.jpg)

## Download application

This application is only available for windows users for now. Work is in progress to make it available for other platforms. 
The application can be downloaded from [Releases](https://github.com/startng/forward-itarj-damianson/releases)

## Contributing

To contribute to this project, we follow the "fork-and-pull" Git workflow:
- **Fork** the repo on Github.
- **Clone** to your local machine
- **Commit** changes to your own branch
- **Push** your work to your fork
- Create and submit a **Pull Request** for review

**Note:** For major changes, open an issue first to discuss what youll like to change. You can also reach me at <mailto:damiansonuchegbu2017@gmail.com>

==> ItarjConsole-0.3.tar.gz: ItarjConsole-0.3/README.md <==
# Itarj Console

Itarj Console is a CLI application created with python. This application is aimed at reducing the rate at which internet users fall for job scams. Users of the application can be able to search the database for Job openings that have been flagged as **scams**.

## Features

Itarj Console provides the following features:

* Beautiful User interface:

  We know that console applications can look plain sometimes 😐. So we decided to spice it up with some colour 😁.

  ![Itarj Cli](https://res.cloudinary.com/damianson/image/upload/w_1000,ar_16:9,c_fill,g_auto,e_sharpen/v1590695595/itarj_demo_mzi0ge.jpg)
* Users can create posts, these posts will be uploaded to the database and other users will be able to see it.
* Users can also search the database for posts using keyword, and the results will be automatically returned through a website on the browser.

  ![Itarj search](https://res.cloudinary.com/damianson/image/upload/w_1000,ar_16:9,c_fill,g_auto,e_sharpen/v1590695596/itarj_search_result_jjrtpv.jpg)

## Download application

This application is only available for windows users for now. Work is in progress to make it available for other platforms. 
The application can be downloaded from [Releases](https://github.com/startng/forward-itarj-damianson/releases)

## Contributing

To contribute to this project, we follow the "fork-and-pull" Git workflow:
- **Fork** the repo on Github.
- **Clone** to your local machine
- **Commit** changes to your own branch
- **Push** your work to your fork
- Create and submit a **Pull Request** for review

**Note:** For major changes, open an issue first to discuss what youll like to change. You can also reach me at <damiansonuchegbu2017@gmail.com>
